==> react_image_annotate_ns_workflow-3.0.9.tgz: package/LazyBrush/BrushRegion.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import { Brush } from "@mui/icons-material";
import TrashIcon from "@mui/icons-material/Delete";
import LockIcon from "@mui/icons-material/Lock";
import UnlockIcon from "@mui/icons-material/LockOpen";
import ReorderIcon from "@mui/icons-material/SwapVert";
import VisibleIcon from "@mui/icons-material/Visibility";
import VisibleOffIcon from "@mui/icons-material/VisibilityOff";
import { Tooltip } from "@mui/material";
import { grey } from "@mui/material/colors";
import Grid from "@mui/material/Grid";
import { createTheme, styled, ThemeProvider } from "@mui/material/styles";
import { makeStyles } from "@mui/styles";
import classnames from "classnames";
import React, { memo, useState } from "react";
import SidebarBoxContainer from "../SidebarBoxContainer";
import styles from "./styles";
var theme = createTheme();
var useStyles = makeStyles(function (theme) {
  return styles;
});
var HeaderSep = styled("div")(function (_ref) {
  var theme = _ref.theme;
  return {
    borderTop: "1px solid ".concat(grey[200]),
    marginTop: 2,
    marginBottom: 2
  };
});

var Chip = function Chip(_ref2) {
  var color = _ref2.color,
      text = _ref2.text,
      index = _ref2.index;
  var classes = useStyles();
  return /*#__PURE__*/React.createElement("span", {
    className: classes.chip,
    onClick: function onClick() {
      return window.brushHighlighted(index);
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: "color",
    style: {
      backgroundColor: color
    }
  }), /*#__PURE__*/React.createElement("div", {
    className: "text"
  }, text));
};

var RowLayout = function RowLayout(_ref3) {
  var header = _ref3.header,
      highlighted = _ref3.highlighted,
      order = _ref3.order,
      classification = _ref3.classification,
      area = _ref3.area,
      tags = _ref3.tags,
      trash = _ref3.trash,
      lock = _ref3.lock,
      visible = _ref3.visible,
      onClick = _ref3.onClick;
  var classes = useStyles();

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      mouseOver = _useState2[0],
      changeMouseOver = _useState2[1];

  return /*#__PURE__*/React.createElement("div", {
    onClick: onClick,
    onMouseEnter: function onMouseEnter() {
      return changeMouseOver(true);
    },
    onMouseLeave: function onMouseLeave() {
      return changeMouseOver(false);
    },
    className: classnames(classes.row, {
      header: header,
      highlighted: highlighted
    })
  }, /*#__PURE__*/React.createElement(Grid, {
    container: true,
    alignItems: "center"
  }, /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 2
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      textAlign: "right",
      paddingRight: 10
    }
  }, order)), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 5
  }, classification), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 2
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      textAlign: "right",
      paddingRight: 6
    }
  }, area)), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 1
  }, trash), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 1
  }, lock), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 1
  }, visible)));
};

var RowHeader = function RowHeader() {
  return /*#__PURE__*/React.createElement(RowLayout, {
    header: true,
    highlighted: false,
    order: /*#__PURE__*/React.createElement(ReorderIcon, {
      className: "icon"
    }),
    classification: /*#__PURE__*/React.createElement("div", {
      style: {
        paddingLeft: 10
      }
    }, "Class"),
    trash: /*#__PURE__*/React.createElement(Tooltip, {
      title: "Delete"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      className: "icon"
    })),
    lock: /*#__PURE__*/React.createElement(Tooltip, {
      title: "Lock/Unlock"
    }, /*#__PURE__*/React.createElement(LockIcon, {
      className: "icon"
    })),
    visible: /*#__PURE__*/React.createElement(Tooltip, {
      title: "Show/Hide"
    }, /*#__PURE__*/React.createElement(VisibleIcon, {
      className: "icon"
    }))
  });
};

var MemoRowHeader = memo(RowHeader);

var Row = function Row(_ref4) {
  var _r$popUp, _r$popUp$classificati;

  var r = _ref4.region,
      highlighted = _ref4.highlighted,
      color = _ref4.color,
      index = _ref4.index,
      delete_annotation = _ref4.delete_annotation,
      setdelete_annotation = _ref4.setdelete_annotation,
      _ref4$brushLines = _ref4.brushLines,
      brushLines = _ref4$brushLines === void 0 ? [] : _ref4$brushLines,
      _ref4$setLines = _ref4.setLines,
      setLines = _ref4$setLines === void 0 ? function () {} : _ref4$setLines;

  var handleLockUnLock = function handleLockUnLock(locked, lock_id) {
    var linessave = _toConsumableArray(brushLines);

    var filter_arr = linessave.filter(function (filters) {
      if (filters.id === lock_id) {
        filters.isLocked = locked;
      }

      return filters;
    });
    setLines(filter_arr);
  };

  var handleShowHide = function handleShowHide(show, show_id) {
    var linessave = _toConsumableArray(brushLines);

    var filter_arr = linessave.filter(function (filters) {
      if (filters.id === show_id) {
        filters.isHide = show;
      }

      return filters;
    });
    setLines(filter_arr);
  };

  return /*#__PURE__*/React.createElement(RowLayout, {
    header: false,
    highlighted: highlighted,
    order: "#".concat(index + 1),
    classification: /*#__PURE__*/React.createElement(Chip, {
      text: (r === null || r === void 0 ? void 0 : (_r$popUp = r.popUp) === null || _r$popUp === void 0 ? void 0 : (_r$popUp$classificati = _r$popUp.classification) === null || _r$popUp$classificati === void 0 ? void 0 : _r$popUp$classificati.label) || "",
      color: color || "#ddd",
      index: index
    }),
    area: "",
    trash: /*#__PURE__*/React.createElement(Tooltip, {
      title: "Delete"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      onClick: function onClick() {
        var linessave = _toConsumableArray(brushLines);

        var filter_arr = linessave.filter(function (filters) {
          return filters.id !== r.id && filters;
        });
        setLines(filter_arr);

        var arr = _toConsumableArray(delete_annotation);

        var delete_arr = linessave.filter(function (filter) {
          return filter.id === r.id && filter;
        });
        arr.push(delete_arr);
        window.undoArray = [].concat(_toConsumableArray(window.undoArray), ["brush"]);
        var obj = {
          brush: delete_arr
        };

        var newArr = _toConsumableArray(window.annotation_redo);

        if (obj.brush !== undefined) {
          newArr.push(obj);
          window.annotation_redo = newArr;
        }

        setdelete_annotation(arr);
        window.brushHighlighted(-1);
      },
      className: "icon2"
    })),
    lock: r.isLocked ? /*#__PURE__*/React.createElement(Tooltip, {
      title: "UnLock"
    }, /*#__PURE__*/React.createElement(LockIcon, {
      onClick: function onClick() {
        handleLockUnLock(false, r.id); // window.brushHighlighted(index)
      },
      className: "icon2"
    })) : /*#__PURE__*/React.createElement(Tooltip, {
      title: "Lock"
    }, /*#__PURE__*/React.createElement(UnlockIcon, {
      onClick: function onClick() {
        handleLockUnLock(true, r.id);
        window.brushHighlighted(-1);
      },
      className: "icon2"
    })),
    visible: r.isHide || r.isHide === undefined ? /*#__PURE__*/React.createElement(Tooltip, {
      title: "Show"
    }, /*#__PURE__*/React.createElement(VisibleOffIcon, {
      onClick: function onClick() {
        handleShowHide(false, r.id);
        window.brushHighlighted(index);
      },
      className: "icon2"
    })) : /*#__PURE__*/React.createElement(Tooltip, {
      title: "Hide"
    }, /*#__PURE__*/React.createElement(VisibleIcon, {
      onClick: function onClick() {
        handleShowHide(true, r.id);
        window.brushHighlighted(-1);
      },
      className: "icon2"
    }))
  });
};

var MemoRow = memo(Row);

var BrushRegion = function BrushRegion(_ref5) {
  var setdelete_annotation = _ref5.setdelete_annotation,
      onChangeVideoTime = _ref5.onChangeVideoTime,
      setLines = _ref5.setLines,
      brushLines = _ref5.brushLines,
      delete_annotation = _ref5.delete_annotation,
      brushHighlight = _ref5.brushHighlight;
  var classes = useStyles();
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(SidebarBoxContainer, {
    title: "Brush Region",
    subTitle: "",
    icon: /*#__PURE__*/React.createElement(Brush, {
      style: {
        color: grey[700]
      }
    }),
    expandedByDefault: true
  }, /*#__PURE__*/React.createElement("div", {
    className: classes.container
  }, /*#__PURE__*/React.createElement(HeaderSep, null), brushLines === null || brushLines === void 0 ? void 0 : brushLines.filter(function (arr, index, self) {
    return index === self.findIndex(function (t) {
      return t.id === arr.id && arr.id;
    });
  }).map(function (r, i) {
    return /*#__PURE__*/React.createElement(MemoRow, Object.assign({
      key: r.id
    }, r, {
      region: r,
      index: i,
      delete_annotation: delete_annotation,
      setdelete_annotation: setdelete_annotation,
      setLines: setLines,
      brushLines: brushLines
    }));
  }))));
};

export default BrushRegion;

==> react_image_annotate_ns_workflow-4.0.1.tgz: package/LazyBrush/BrushRegion.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import { Brush } from "@mui/icons-material";
import TrashIcon from "@mui/icons-material/Delete";
import LockIcon from "@mui/icons-material/Lock";
import UnlockIcon from "@mui/icons-material/LockOpen";
import ReorderIcon from "@mui/icons-material/SwapVert";
import VisibleIcon from "@mui/icons-material/Visibility";
import VisibleOffIcon from "@mui/icons-material/VisibilityOff";
import { Tooltip } from "@mui/material";
import { grey } from "@mui/material/colors";
import Grid from "@mui/material/Grid";
import { createTheme, styled, ThemeProvider } from "@mui/material/styles";
import { makeStyles } from "@mui/styles";
import classnames from "classnames";
import React, { memo, useState } from "react";
import SidebarBoxContainer from "../SidebarBoxContainer";
import { asMutable } from "seamless-immutable";
import styles from "./styles";
var theme = createTheme();
var useStyles = makeStyles(function (theme) {
  return styles;
});
var HeaderSep = styled("div")(function (_ref) {
  var theme = _ref.theme;
  return {
    borderTop: "1px solid ".concat(grey[200]),
    marginTop: 2,
    marginBottom: 2
  };
});

var Chip = function Chip(_ref2) {
  var color = _ref2.color,
      text = _ref2.text,
      index = _ref2.index;
  var classes = useStyles();
  return /*#__PURE__*/React.createElement("span", {
    className: classes.chip,
    onClick: function onClick() {
      return window.brushHighlighted(index);
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: "color",
    style: {
      backgroundColor: color
    }
  }), /*#__PURE__*/React.createElement("div", {
    className: "text"
  }, text));
};

var RowLayout = function RowLayout(_ref3) {
  var header = _ref3.header,
      highlighted = _ref3.highlighted,
      order = _ref3.order,
      classification = _ref3.classification,
      area = _ref3.area,
      tags = _ref3.tags,
      trash = _ref3.trash,
      lock = _ref3.lock,
      visible = _ref3.visible,
      onClick = _ref3.onClick;
  var classes = useStyles();

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      mouseOver = _useState2[0],
      changeMouseOver = _useState2[1];

  return /*#__PURE__*/React.createElement("div", {
    onClick: onClick,
    onMouseEnter: function onMouseEnter() {
      return changeMouseOver(true);
    },
    onMouseLeave: function onMouseLeave() {
      return changeMouseOver(false);
    },
    className: classnames(classes.row, {
      header: header,
      highlighted: highlighted
    })
  }, /*#__PURE__*/React.createElement(Grid, {
    container: true,
    alignItems: "center"
  }, /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 2
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      textAlign: "right",
      paddingRight: 10
    }
  }, order)), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 5
  }, classification), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 2
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      textAlign: "right",
      paddingRight: 6
    }
  }, area)), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 1
  }, trash), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 1
  }, lock), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 1
  }, visible)));
};

var RowHeader = function RowHeader(_ref4) {
  var _asMutable, _asMutable2, _asMutable3;

  var regions = _ref4.regions,
      brushLines = _ref4.brushLines,
      setLines = _ref4.setLines,
      setdelete_annotation = _ref4.setdelete_annotation,
      delete_annotation = _ref4.delete_annotation;
  var main_region = (_asMutable = asMutable(regions || [])) === null || _asMutable === void 0 ? void 0 : _asMutable.length;
  var visible = (_asMutable2 = asMutable(regions || [])) === null || _asMutable2 === void 0 ? void 0 : _asMutable2.filter(function (item) {
    return !item.isHide || item.isHide === undefined;
  });
  var locked = (_asMutable3 = asMutable(regions || [])) === null || _asMutable3 === void 0 ? void 0 : _asMutable3.every(function (item) {
    return item.isLocked === false || item.isLocked === undefined;
  });

  var handleChangeRegion = function handleChangeRegion() {
    var action = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var linessave = _toConsumableArray(brushLines); // eslint-disable-next-line no-unused-expressions


    var final = linessave === null || linessave === void 0 ? void 0 : linessave.map(function (r) {
      return Object.assign(_objectSpread({}, r, action));
    });
    setLines(final);
  };

  return /*#__PURE__*/React.createElement(RowLayout, {
    header: true,
    highlighted: false,
    order: /*#__PURE__*/React.createElement(ReorderIcon, {
      className: "icon"
    }),
    classification: /*#__PURE__*/React.createElement("div", {
      style: {
        paddingLeft: 10
      }
    }, "Class"),
    trash: /*#__PURE__*/React.createElement(Tooltip, {
      title: "Delete",
      placement: "right"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      className: "icon",
      onClick: function onClick() {
        var arr = _toConsumableArray(delete_annotation);

        setLines([]);
        arr.push(regions);
        setdelete_annotation(arr.flat());
      }
    })),
    lock: /*#__PURE__*/React.createElement(Tooltip, {
      title: "Lock/Unlock",
      placement: "right"
    }, locked ? /*#__PURE__*/React.createElement(UnlockIcon, {
      className: "icon",
      onClick: function onClick() {
        // eslint-disable-next-line no-unused-expressions
        handleChangeRegion({
          isLocked: true
        });
      }
    }) : /*#__PURE__*/React.createElement(LockIcon, {
      className: "icon",
      onClick: function onClick() {
        // eslint-disable-next-line no-unused-expressions
        handleChangeRegion({
          isLocked: false
        });
      }
    })),
    visible: /*#__PURE__*/React.createElement(Tooltip, {
      title: "Show/Hide",
      placement: "right"
    }, visible.length ? /*#__PURE__*/React.createElement(VisibleIcon, {
      className: "icon",
      onClick: function onClick() {
        // eslint-disable-next-line no-unused-expressions
        handleChangeRegion({
          isHide: true
        });
      }
    }) : /*#__PURE__*/React.createElement(VisibleOffIcon, {
      className: "icon",
      onClick: function onClick() {
        // eslint-disable-next-line no-unused-expressions
        handleChangeRegion({
          isHide: false
        });
      }
    }))
  });
};

var MemoRowHeader = RowHeader;

var Row = function Row(_ref5) {
  var _r$popUp, _r$popUp$classificati;

  var r = _ref5.region,
      highlighted = _ref5.highlighted,
      color = _ref5.color,
      index = _ref5.index,
      delete_annotation = _ref5.delete_annotation,
      setdelete_annotation = _ref5.setdelete_annotation,
      _ref5$brushLines = _ref5.brushLines,
      brushLines = _ref5$brushLines === void 0 ? [] : _ref5$brushLines,
      _ref5$setLines = _ref5.setLines,
      setLines = _ref5$setLines === void 0 ? function () {} : _ref5$setLines;

  var handleLockUnLock = function handleLockUnLock(locked, lock_id) {
    var linessave = _toConsumableArray(brushLines);

    var filter_arr = linessave.filter(function (filters) {
      if (filters.id === lock_id) {
        filters.isLocked = locked;
      }

      return filters;
    });
    setLines(filter_arr);
  };

  var handleShowHide = function handleShowHide(show, show_id) {
    var linessave = _toConsumableArray(brushLines);

    var filter_arr = linessave.filter(function (filters) {
      if (filters.id === show_id) {
        filters.isHide = show;
      }

      return filters;
    });
    setLines(filter_arr);
  };

  return /*#__PURE__*/React.createElement(RowLayout, {
    header: false,
    highlighted: highlighted,
    order: "#".concat(index + 1),
    classification: /*#__PURE__*/React.createElement(Chip, {
      text: (r === null || r === void 0 ? void 0 : (_r$popUp = r.popUp) === null || _r$popUp === void 0 ? void 0 : (_r$popUp$classificati = _r$popUp.classification) === null || _r$popUp$classificati === void 0 ? void 0 : _r$popUp$classificati.label) || "",
      color: color || "#ddd",
      index: index
    }),
    area: "",
    trash: /*#__PURE__*/React.createElement(Tooltip, {
      title: "Delete",
      placement: "right"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      onClick: function onClick() {
        var linessave = _toConsumableArray(brushLines);

        var filter_arr = linessave.filter(function (filters) {
          return filters.id !== r.id && filters;
        });
        setLines(filter_arr);

        var arr = _toConsumableArray(delete_annotation);

        var delete_arr = linessave.filter(function (filter) {
          return filter.id === r.id && filter;
        });
        arr.push(delete_arr);
        window.undoArray = [].concat(_toConsumableArray(window.undoArray), ["delete~".concat(r.id)]);
        /** create DeleteBrush Arr */

        window.deleteBrush = [].concat(_toConsumableArray(window.deleteBrush), [arr]).flat();
        setdelete_annotation(arr.flat());
        window.brushHighlighted(-1);
      },
      className: "icon2"
    })),
    lock: r.isLocked ? /*#__PURE__*/React.createElement(Tooltip, {
      title: "UnLock",
      placement: "right"
    }, /*#__PURE__*/React.createElement(LockIcon, {
      onClick: function onClick() {
        handleLockUnLock(false, r.id); // window.brushHighlighted(index)
      },
      className: "icon2"
    })) : /*#__PURE__*/React.createElement(Tooltip, {
      title: "Lock",
      placement: "right"
    }, /*#__PURE__*/React.createElement(UnlockIcon, {
      onClick: function onClick() {
        handleLockUnLock(true, r.id);
        window.brushHighlighted(-1);
      },
      className: "icon2"
    })),
    visible: r.isHide || r.isHide === undefined ? /*#__PURE__*/React.createElement(Tooltip, {
      title: "Show",
      placement: "right"
    }, /*#__PURE__*/React.createElement(VisibleOffIcon, {
      onClick: function onClick() {
        handleShowHide(false, r.id);
        window.brushHighlighted(index);
      },
      className: "icon2"
    })) : /*#__PURE__*/React.createElement(Tooltip, {
      title: "Hide",
      placement: "right"
    }, /*#__PURE__*/React.createElement(VisibleIcon, {
      onClick: function onClick() {
        handleShowHide(true, r.id);
        window.brushHighlighted(-1);
      },
      className: "icon2"
    }))
  });
};

var MemoRow = memo(Row);

var BrushRegion = function BrushRegion(_ref6) {
  var setdelete_annotation = _ref6.setdelete_annotation,
      onChangeVideoTime = _ref6.onChangeVideoTime,
      setLines = _ref6.setLines,
      brushLines = _ref6.brushLines,
      delete_annotation = _ref6.delete_annotation,
      brushHighlight = _ref6.brushHighlight;
  var classes = useStyles();
  var brush_region_arr = brushLines === null || brushLines === void 0 ? void 0 : brushLines.filter(function (arr, index, self) {
    return index === self.findIndex(function (t) {
      return t.id === arr.id && arr.id;
    });
  });
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(SidebarBoxContainer, {
    title: "Brush Region",
    subTitle: "",
    icon: /*#__PURE__*/React.createElement(Brush, {
      style: {
        color: grey[700]
      }
    }),
    expandedByDefault: true
  }, /*#__PURE__*/React.createElement("div", {
    className: classes.container
  }, /*#__PURE__*/React.createElement(MemoRowHeader, {
    regions: brush_region_arr // onChangeRegion={onChangeRegion}
    // onDeleteRegion={onDeleteRegion}
    ,
    delete_annotation: delete_annotation,
    setdelete_annotation: setdelete_annotation,
    brushLines: brushLines,
    setLines: setLines
  }), /*#__PURE__*/React.createElement(HeaderSep, null), brush_region_arr.map(function (r, i) {
    return /*#__PURE__*/React.createElement(MemoRow, Object.assign({
      key: r.id
    }, r, {
      region: r,
      index: i,
      delete_annotation: delete_annotation,
      setdelete_annotation: setdelete_annotation,
      setLines: setLines,
      brushLines: brushLines
    }));
  }))));
};

export default BrushRegion;
